==> zither-1.1.18.tar.gz: zither_prj/apollon/monitor_manu.php <==
<HTML>
<HEAD>
<meta http-equiv="Content-Type" content="text/html; charset=EUC-JP">
<TITLE>Zither server Administration tool 'Apollon'</TITLE>

<style type="text/css">
<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }

.example {
width: 100%;
max-width: 80px;
min-width: 50px;
}

-->
</style>


</HEAD>


<?php
require("./total.inc");
require("./enco.inc");

print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

$quedata = enco($_GET["QUE_DATA"]);
//$youname = enco($_GET["USER_NAME"]);

//$auth_user = $_SERVER["PHP_AUTH_USER"];
//$auth_pw = $_SERVER["PHP_AUTH_PW"];

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td>");
if(0 == strcmp($quedata, "KENSAKU")){
   print("<font color='ffffff'><b>顼ޥ˥奢</b></font>");
   }
else {
   print("<font color='ffffff'><b>ƻޥ˥奢</b></font>");
   }
print("</td></tr>");
print("</table>");
print("<br>");



//if(0 != strcmp($auth_user, $youname)){
//   echo "븢¤ʤˤϤޤ\n";
//   exit;
//   }

print("<TABLE border='1' bgcolor='#FFFFFF' cellspacing='0' cellpadding='0' width=80%>\n");


if(0 == strcmp($quedata, "KENSAKU")){
   print("<tr>");
   print("<td>");
      print("(顼Ȥϡ) <br>");
      print("<br>");
      print("˸Ф줿顼Υ򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }


if(0 == strcmp($quedata, "KENSAKU2")){
   print("<tr>");
   print("<td>");
      print("(ƻθȤϡ) <br>");
      print("<br>");
      print("ꤵƤƻܤ򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }


if(0 == strcmp($quedata, "KENSAKU3")){
   print("<tr>");
   print("<td>");
      print("(ƻ륯饤ȤθȤϡ) <br>");
      print("<br>");
      print("Ͽδƻ륯饤Ȥ򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }


if(0 == strcmp($quedata, "KENSAKU4")){
   print("<tr>");
   print("<td>");
      print("(ƻ֥åθȤϡ) <br>");
      print("<br>");
      print("Ͽδƻ֥å򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }



if(0 == strcmp($quedata, "ERRCOMP")){
   print("<tr>");
   print("<td>");
      print("(׾Ȥϡ) <br>");
      print("<br>");
      print("ƻ뤵ƤIPƤФƾꤷ¿¬Ƥ˥դϤޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }




if(0 == strcmp($quedata, "MONITOR")){
   print("<tr>");
   print("<td>");
      print("(ƻ°Ȥϡ) <br>");
      print("<br>");
      print("ƻ°ϥݡȥϤSNMPϤΤդĤޤ<br>");
      print("<br>");
      print("PORT:  ݡȥξ򤷤Ƥ<br>");
      print("SNMP:  SNMPѤ򤷤Ƥ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PROTO")){
   print("<tr>");
   print("<td>");
      print("(ץȥȤϡ) <br>");
      print("<br>");
      print("ƻ°ǥݡȥ򤷤ˡˡǽǤ<br>");
      print("<br>");
      print("UDP:   UDPݡȥ<br>");
      print("TCP:   TCPݡȥ<br>");
      print("ICMP:  ICMP̳ǧ<br>");
      print("SMTP:  SMTPơǧ<br>");
      print("URL:   URLơǧ<br>");
      print("SNTP:  NTPˤꥵФȤλ֤κǧ<br>");
      print("HOST:  DNSˤ̾褬뤫γǧ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "CIP")){
   print("<tr>");
   print("<td>");
      print("(ƻIPHOSTȤϡ) <br>");
      print("<br>");
      print("ƻIPɥ쥹URLϥۥ̾ˤʤޤ<br>");
      print("DNSޤΤǡIPɥ쥹ǤɬפϤޤ<br>");
      print("<br>");
      print("UDP,TCP,ICMP,SMTP,SNTP IPۥ̾ꤷƤ<br>");
      print("URLξϰʲ˥ե̾ޤǻꤷƤ<br>");
      print("....zither.ms-n.com/index.html.....<br>");
      print("HOSTξϤ̾DNSǰȤ뤫ɤγǧԤޤ<br>");
      print("ʤ䡢꤬0ξϥ顼ˤʤޤIPɥ쥹ꤷƤ⥨顼ˤʤޤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PRINO")){
   print("<tr>");
   print("<td>");
      print("(ץ饤ƥȤϡ) <br>");
      print("<br>");
      print("δƻνޤ<br>");
      print("٤ˤäƥ顼ФƤzither䥢ݥбѤäƤޤ<br>");
      print("᡼ˤ٤λ꤬Ԥޤ<br>");
      print("<br>");
      print("1ϺǤ⤤顼ǤݥǤ֤ɽޤ<br>");
      print("2̾Υ顼Ǥ1Ȥΰ㤤ɽޥˤʤǤ<br>");
      print("3ʾοϥ顼Ǥ᡼Ԥޤ<br>");
      print("4ϥƥȥ⡼ɤˤʤޤƥȥ⡼ɤФɽޤ顼ФʤƤɽޤΤǡǥХåѤƤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PORT")){
   print("<tr>");
   print("<td>");
      print("(ݡȤȤϡ) <br>");
      print("ݡֹǵƤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PINFO")){
   print("<tr>");
   print("<td>");
      print("(ƻξȤϡ) <br>");
      print("ƻξܺ٤˵뤳Ȥᤷޤ<br>");
      print("񼰤줹뤳Ȥǡ䤹ʤޤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "FREE1")){
   print("<tr>");
   print("<td>");
      print("(ƻξȤϡ) <br>");
      print("δƻܤΰ̣Ūʤɤ򵭺ܤƤȤǡƤϥ᡼ȿǤޤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "COM_SNMP")){
   print("<tr>");
   print("<td>");
      print("(OIDȤϡ) <br>");
      print("SNMPOIDꤷƤޤCAl[*[+[*[ ʤɤȤ뤳ȤǡOIDƱΤη׻ǽǤ<br>");
      print("<br>");
      print("cal[IF-MIB::ifMtu.10[-[IF-MIB::ifIndex.9[<br>");
      print("cal[.1.3.6.1.4.1.2021.11.9.0[+[.1.3.6.1.4.1.2021.11.10.0[<br>");
      print("<br>");
      print("̤ФͤϰʲΤΤǽǤ<br>");
      print("<br>");
      print("!taro<br>");
      print("=taro<br>");
      print("+10<br>");
      print("-10<br>");
      print("!ʤ=+礭-Ͼ˿Ȥʤޤ<br>");
      print("<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PORT_SNMP")){
   print("<tr>");
   print("<td>");
      print("(SNMP̾Ȥϡ) <br>");
      print("оSNMP³ɬפʥ̾ˤʤޤ<br>");
      print("SNMP¦Ǵƻ륵IPĤƤ뤳ȤǧƤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

echo "</table>";

?>

</BODY>
</HTML>

==> zither-1.1.23.tar.gz: zither_prj/apollon/monitor_manu.php <==
<HTML>
<HEAD>
<meta http-equiv="Content-Type" content="text/html; charset=EUC-JP">
<TITLE>Zither server Administration tool 'Apollon'</TITLE>

<style type="text/css">
<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }

.example {
width: 100%;
max-width: 80px;
min-width: 50px;
}

-->
</style>


</HEAD>


<?php
require("./total.inc");
require("./enco.inc");

print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

$quedata = enco($_GET["QUE_DATA"]);
//$youname = enco($_GET["USER_NAME"]);

//$auth_user = $_SERVER["PHP_AUTH_USER"];
//$auth_pw = $_SERVER["PHP_AUTH_PW"];

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td>");
if(0 == strcmp($quedata, "KENSAKU")){
   print("<font color='ffffff'><b>顼ޥ˥奢</b></font>");
   }
else {
   print("<font color='ffffff'><b>ƻޥ˥奢</b></font>");
   }
print("</td></tr>");
print("</table>");
print("<br>");



//if(0 != strcmp($auth_user, $youname)){
//   echo "븢¤ʤˤϤޤ\n";
//   exit;
//   }

print("<TABLE border='1' bgcolor='#FFFFFF' cellspacing='0' cellpadding='0' width=80%>\n");


if(0 == strcmp($quedata, "KENSAKU")){
   print("<tr>");
   print("<td>");
      print("(顼Ȥϡ) <br>");
      print("<br>");
      print("˸Ф줿顼Υ򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }


if(0 == strcmp($quedata, "KENSAKU2")){
   print("<tr>");
   print("<td>");
      print("(ƻθȤϡ) <br>");
      print("<br>");
      print("ꤵƤƻܤ򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }


if(0 == strcmp($quedata, "KENSAKU3")){
   print("<tr>");
   print("<td>");
      print("(ƻ륯饤ȤθȤϡ) <br>");
      print("<br>");
      print("Ͽδƻ륯饤Ȥ򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }


if(0 == strcmp($quedata, "KENSAKU4")){
   print("<tr>");
   print("<td>");
      print("(ƻ֥åθȤϡ) <br>");
      print("<br>");
      print("Ͽδƻ֥å򸡺Ƥγǧޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }



if(0 == strcmp($quedata, "ERRCOMP")){
   print("<tr>");
   print("<td>");
      print("(׾Ȥϡ) <br>");
      print("<br>");
      print("ƻ뤵ƤIPƤФƾꤷ¿¬Ƥ˥դϤޤ<br>");
      print("<br>");
      print("(ñʻȤ) <br>");
      print("<br>");
      print("ɬפʹܤϽ񤭹ǸƤ<br>");
      print("¦åܥå˥å뤳Ȥǡʤʳˤʰ̣ˤʤޤ<br>");
      print("ܤˡδޤޤʪϴޤޤƤ򸡺ޤ<br>");
      print("ξΡϲ餫ʸȤƸޤ<br>");
      print("㡧%abcde% <br>");
      print("ξ硢㲿餫ʸabcde㲿餫ʸ䡡ȤƸޤ <br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }




if(0 == strcmp($quedata, "MONITOR")){
   print("<tr>");
   print("<td>");
      print("(ƻ°Ȥϡ) <br>");
      print("<br>");
      print("ƻ°ϥݡȥϤSNMPϤΤդĤޤ<br>");
      print("<br>");
      print("PORT:  ݡȥξ򤷤Ƥ<br>");
      print("SNMP:  SNMPѤ򤷤Ƥ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PROTO")){
   print("<tr>");
   print("<td>");
      print("(ץȥȤϡ) <br>");
      print("<br>");
      print("ƻ°ǥݡȥ򤷤ˡˡǽǤ<br>");
      print("<br>");
      print("UDP:   UDPݡȥ<br>");
      print("TCP:   TCPݡȥ<br>");
      print("ICMP:  ICMP̳ǧ<br>");
      print("SMTP:  SMTPơǧ<br>");
      print("FTP:   FTPơǧ<br>");
      print("POP:   POPơǧ<br>");
      print("SSH:   SSHơǧ<br>");
      print("URL:   URLơǧ<br>");
      print("SNTP:  NTPˤꥵФȤλ֤κǧ<br>");
      print("HOST:  DNSˤ̾褬뤫γǧ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "CIP")){
   print("<tr>");
   print("<td>");
      print("(ƻIPHOSTȤϡ) <br>");
      print("<br>");
      print("ƻIPɥ쥹URLϥۥ̾ˤʤޤ<br>");
      print("DNSޤΤǡIPɥ쥹ǤɬפϤޤ<br>");
      print("<br>");
      print("UDP,TCP,ICMP,SMTP,FTP,SSH,POP,SNTP IPۥ̾ꤷƤ<br>");
      print("URLξϰʲ˥ե̾ޤǻꤷƤ<br>");
      print("....zither.ms-n.com/index.html.....<br>");
      print("HOSTξϤ̾DNSǰȤ뤫ɤγǧԤޤ<br>");
      print("ʤ䡢꤬0ξϥ顼ˤʤޤIPɥ쥹ꤷƤ⥨顼ˤʤޤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PRINO")){
   print("<tr>");
   print("<td>");
      print("(ץ饤ƥȤϡ) <br>");
      print("<br>");
      print("δƻνޤ<br>");
      print("٤ˤäƥ顼ФƤzither䥢ݥбѤäƤޤ<br>");
      print("᡼ˤ٤λ꤬Ԥޤ<br>");
      print("<br>");
      print("1ϺǤ⤤顼ǤݥǤ֤ɽޤ<br>");
      print("2̾Υ顼Ǥ1Ȥΰ㤤ɽޥˤʤǤ<br>");
      print("3ʾοϥ顼Ǥ᡼Ԥޤ<br>");
      print("4ϥƥȥ⡼ɤˤʤޤƥȥ⡼ɤФɽޤ顼ФʤƤɽޤΤǡǥХåѤƤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PORT")){
   print("<tr>");
   print("<td>");
      print("(ݡȤȤϡ) <br>");
      print("ݡֹǵƤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PINFO")){
   print("<tr>");
   print("<td>");
      print("(ƻξȤϡ) <br>");
      print("ƻξܺ٤˵뤳Ȥᤷޤ<br>");
      print("񼰤줹뤳Ȥǡ䤹ʤޤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "FREE1")){
   print("<tr>");
   print("<td>");
      print("(ƻξȤϡ) <br>");
      print("δƻܤΰ̣Ūʤɤ򵭺ܤƤȤǡƤϥ᡼ȿǤޤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "COM_SNMP")){
   print("<tr>");
   print("<td>");
      print("(OIDȤϡ) <br>");
      print("SNMPOIDꤷƤޤCAl[*[+[*[ ʤɤȤ뤳ȤǡOIDƱΤη׻ǽǤ<br>");
      print("<br>");
      print("cal[IF-MIB::ifMtu.10[-[IF-MIB::ifIndex.9[<br>");
      print("cal[.1.3.6.1.4.1.2021.11.9.0[+[.1.3.6.1.4.1.2021.11.10.0[<br>");
      print("<br>");
      print("̤ФͤϰʲΤΤǽǤ<br>");
      print("<br>");
      print("!taro<br>");
      print("=taro<br>");
      print("+10<br>");
      print("-10<br>");
      print("!ʤ=+礭-Ͼ˿Ȥʤޤ<br>");
      print("<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

if(0 == strcmp($quedata, "PORT_SNMP")){
   print("<tr>");
   print("<td>");
      print("(SNMP̾Ȥϡ) <br>");
      print("оSNMP³ɬפʥ̾ˤʤޤ<br>");
      print("SNMP¦Ǵƻ륵IPĤƤ뤳ȤǧƤ<br>");
      print("<br>");
   print("</td>");
   print("</tr>");
   }

echo "</table>";

?>

</BODY>
</HTML>
